# Receptor tyrosine kinase

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

import numpy as np 

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants.
    # original model had reactions that omitted enzymes as substrates e.g. BARK
    # convert unit from 1/s to 1/uM.s by dividing by conc of enzyme
    # all reactions were irreversible, made reversible by letting kr ~= 0

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    bigNum = 1e6
    fastKineticConstant = bigNum
    smallReverse = 1/bigNum
    medReverse = np.sqrt(smallReverse)


    # Reaction 1: Ligand binds receptor, which phosphorylates receptor (L + K1 <=> K1P )
    k_1p = 100 # guess
    k_1m = smallReverse

    # Reaction 2: form complex of LK1 with K2, the other RTK in the dimer
    k_2p = fastKineticConstant
    k_2m = smallReverse

    # Reaction 3: autophosphorylation of second RTK and dissociation of RTK dimer complex
    k_3p = fastKineticConstant
    k_3m = smallReverse
    
    k_kinetic = [
        k_1p, k_2p, k_3p,
        k_1m,k_2m, k_3m
        ]

    # CONSTRAINTS
    N_cT = []
    K_C = []


    # volume vector
    W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))

    return (k_kinetic, [N_cT], K_C, W) 













